@@ -544,20 +544,23 @@ out:
 /*
  * gvm_media_changed - generic media change handler.
  *
- * This is called on a UDI in response to a media change event.  We have to
- * decipher the storage media type to run the appropriate media-present check.
- * Then, if there is indeed media in the drive, we enforce the appropriate
- * policy.
+ * This is called on a UDI and the media's parent device in response to a media
+ * change event.  We have to decipher the storage media type to run the
+ * appropriate media-present check.  Then, if there is indeed media in the
+ * drive, we enforce the appropriate policy.
  *
  * At the moment, we only handle CD-ROM and DVD drives.
  */
 static void
-gvm_media_changed (const char *udi)
+gvm_media_changed (const char *udi, const char *storage_device)
 {
 	char *media_type;
 
-	/* get HAL's interpretation of our media type */
-	media_type = hal_device_get_property_string (hal_ctx, udi, 
+	/*
+	 * Get HAL's interpretation of our media type.  Note that we must check
+	 * the storage device and not this UDI
+	 */
+	media_type = hal_device_get_property_string (hal_ctx, storage_device, 
 						     "storage.drive_type");
 	if (!media_type) {
 		warn ("cannot get storage.drive_type\n");
@@ -618,7 +621,7 @@ hal_device_added (LibHalContext *ctx __attribute__((__unused__)),
 					  "storage.removable")) {
 		/* we handle media change events separately */
 		dbg ("Changed: %s\n", device);
-		gvm_media_changed (udi);
+		gvm_media_changed (udi, storage_device);
 		goto out;
 	}
 	
